==> kreatecd-0.2.2.tar.gz: kreatecd-0.2.2/kreatecd/AudioFile.h <==
// KreateCD - CD recording software for the K desktop environment
//
// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#include <qobject.h>

class KProcess;

class AudioFile : public QObject
 {
  Q_OBJECT;

  public:
    enum Sample_Endian{Endian_Little,Endian_Big};
    enum Sample_Format{Samples_PCM};
    enum Sample_Size{Samples_8Bit,Samples_16Bit,Samples_32Bit};

    AudioFile(void);
    ~AudioFile(void);
    int  identifyFile(const char *filename);
    int  setupCDTrack(const char *filename);
    int getSelectedDuration(void);
    int getAbsoluteDuration(void);

    float getBoost(void);
    float getBalance(void);
    long int getStartPos(void);
    long int getEndPos(void);
    void setStartPos(long int pos);
    void setEndPos(long int pos);
    void setBoost(float boost);
    void setBalance(float balance);
    void setMaxBoost(void);


    enum Sample_Endian   getEndian(void);
    enum Sample_Size     getSampleSize(void);
    int                  getChannels(void);
    long int             getSampleRate(void);
    void                 getFormat(char *formatstring);
    int                  needImage(void);
    int                  buildImage(const char *fn);
    int                  scanImage(void);

    int      buildImageFork(const char *fn,int playmode);
    float    maximumBoost(const char *fn);

  signals:
    void                 audioPlayPosition(int block);

  public slots:
    void                 playAudio(long int position=-1);
    void                 stopAudio(void);
    void                 setAudioPosition(int frame);
    void                 setAudioBoost(float boost);
    void                 setAudioBalance(float balance);

  private slots:

    void buildImageExit(KProcess *);
    void buildImageMsg(KProcess *,char *buf,int len);

    void scanImageExit(KProcess *);
    void scanImageMsg(KProcess *,char *buf,int len);

    void playAudioMsg(KProcess *,char *buf,int len);
    void playAudioExit(KProcess *);
    void playAudioTrigger(void);


  private:
    static const int Read_Cachesize=1024;
    static const int Write_Cachesize=1024;

    int      identifyMSWave(void);

    int  openWrite(const char *wfilename);
    int  writeCDDASample(float msample);
    int  flushCDDABuffer(void);
    void closeWrite(void);

    int  readLEShort (long int  *mshort,int words=1);
    int  readLELong  (long int  *mlong,int words=1);
    int  readBEShort (long int  *mshort,int words=1);
    int  readBELong  (long int  *mlong,int words=1);
    int  readChar    (long int  *mchar,int words=1);
    int  readCharUS  (long int  *mchar,int words=1);
    int  readShort   (long int  *mshort,int words=1);
    int  readLong    (long int  *mlong,int words=1);
    int  readString  (char      *mstring,int length);
    int  skipRead    (int        bytes);

    int  openRead    (const char*mfilename);
    void closeRead   (void);

    int  positionSample(long int sample);
    int  readSample(long int  *sample);
    int  fillSampleBuffer(void);



    int                          AudioFD;
    int                          AudioCached;
    long int                     AudioPos;
    int                          AudioPointer;
    long int                    *AudioBuffer;
    unsigned char               *ReadBuffer;

    int                          ImageFD;
    int                          ImageContent;
    unsigned char               *ImageBuffer;
    int                          DisableSwap;
    long int                     AudioPosition;


    enum Sample_Endian           SampleEndian;
    enum Sample_Format           SampleFormat;
    int                          SampleChannels;
    enum Sample_Size             SampleSize;
    long int                     SampleRate;
    int                          SampleBytes;
    long int                     DataPos;
    long int                     DataSize; 
    long int                     DataSamples;
    long int                     SelectedStart;
    long int                     SelectedEnd;

    float                        BoostFactor;
    float                        Balance;
    float                        MaxBoost;

    char                         Format[16];
    char                         FileName[1024];

    class ProgressDialog        *ImagizeDialog;
    int                          ImagizeFlag;

    char                         linebuffer[64];

    class Fork                  *AudioFork;
    class QTimer                *AudioTimer;
    long int                     startAudio;

    char                         OutLine[64];


 };

==> kreatecd-0.3.0.tar.gz: kreatecd-0.3.0/kreatecd/AudioFile.h <==
// KreateCD - CD recording software for the K desktop environment
//
// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#include <qobject.h>
#include <unistd.h>

class KProcess;

class AudioFile : public QObject
 {
  Q_OBJECT;

  public:
    enum Sample_Endian{Endian_Little,Endian_Big};
    enum Sample_Format{Samples_PCM};
    enum Sample_Size{Samples_8Bit,Samples_16Bit,Samples_32Bit};

    AudioFile(void);
    ~AudioFile(void);
    int  identifyFile(const char *filename);
    int  setupCDTrack(const char *filename);
    int getSelectedDuration(void);
    int getAbsoluteDuration(void);

    float getBoost(void);
    float getBalance(void);
    long int getStartPos(void);
    long int getEndPos(void);
    void setStartPos(long int pos);
    void setEndPos(long int pos);
    void setBoost(float boost);
    void setBalance(float balance);
    void setMaxBoost(void);


    enum Sample_Endian   getEndian(void);
    enum Sample_Size     getSampleSize(void);
    int                  getChannels(void);
    long int             getSampleRate(void);
    void                 getFormat(char *formatstring);
    int                  needImage(void);
    int                  buildImage(const char *fn);
    int                  scanImage(void);

    int      buildImageFork(const char *fn,int playmode);
    float    maximumBoost(const char *fn);

  signals:
    void                 audioPlayPosition(int block);

  public slots:
    void                 playAudio(long int position=-1);
    void                 stopAudio(void);
    void                 setAudioPosition(int frame);
    void                 setAudioBoost(float boost);
    void                 setAudioBalance(float balance);

  private slots:

    void buildImageExit(KProcess *);
    void buildImageMsg(KProcess *,char *buf,int len);

    void scanImageExit(KProcess *);
    void scanImageMsg(KProcess *,char *buf,int len);

    void playAudioMsg(KProcess *,char *buf,int len);
    void playAudioExit(KProcess *);
    void playAudioTrigger(void);


  private:
    static const int Read_Cachesize=1024;
    static const int Write_Cachesize=1024;

    int      identifyMSWave(void);

    int  openWrite(const char *wfilename);
    int  flushCDDABuffer(void);
    void closeWrite(void);

    int  readLEShort (long int  *mshort,int words=1);
    int  readLELong  (long int  *mlong,int words=1);
    int  readBEShort (long int  *mshort,int words=1);
    int  readBELong  (long int  *mlong,int words=1);
    int  readChar    (long int  *mchar,int words=1);
    int  readCharUS  (long int  *mchar,int words=1);
    int  readShort   (long int  *mshort,int words=1);
    int  readLong    (long int  *mlong,int words=1);
    int  skipRead    (int        bytes);

    int  openRead    (const char*mfilename);
    void closeRead   (void);

    int  positionSample(long int sample);
    int  fillSampleBuffer(void);

    int                          AudioFD;
    int                          AudioCached;
    long int                     AudioPos;
    int                          AudioPointer;
    long int                    *AudioBuffer;
    unsigned char               *ReadBuffer;

    int                          ImageFD;
    int                          ImageContent;
    unsigned char               *ImageBuffer;
    int                          DisableSwap;
    long int                     AudioPosition;


    enum Sample_Endian           SampleEndian;
    enum Sample_Format           SampleFormat;
    int                          SampleChannels;
    enum Sample_Size             SampleSize;
    long int                     SampleRate;
    int                          SampleBytes;
    long int                     DataPos;
    long int                     DataSize; 
    long int                     DataSamples;
    long int                     SelectedStart;
    long int                     SelectedEnd;

    float                        BoostFactor;
    float                        Balance;
    float                        MaxBoost;

    char                         Format[16];
    char                         FileName[1024];

    class ProgressDialog        *ImagizeDialog;
    int                          ImagizeFlag;

    char                         linebuffer[64];

    class Fork                  *AudioFork;
    class QTimer                *AudioTimer;
    long int                     startAudio;

    char                         OutLine[64];


    inline int readString(char *mstring,int length)
     {
      if (read(AudioFD,mstring,length)!=length) return(0);
      return(1);
     }

    inline int readSample(long int *sample)
     {
      if (AudioCached<=AudioPointer)
       {
        if (!fillSampleBuffer()) return(0);
       }
      *sample=AudioBuffer[AudioPointer++];
      return(1);
     }

    inline int writeCDDASample(float msample)
     {
      long int xsample;

      xsample=(long int )msample;

      if (ImageContent>=Write_Cachesize)
       {
        if (!flushCDDABuffer()) return(0);
       }

      if (xsample>32767) xsample=32767;
      if (xsample<-32768) xsample=-32768;

      if (DisableSwap)
       {
        *(short int *) (ImageBuffer+2*ImageContent)=xsample;
        ++ImageContent;
        return(1);
       }

#ifdef WORDS_BIGENDIAN
      *(short int *) (ImageBuffer+2*ImageContent)=xsample;
#else
      ImageBuffer[2*ImageContent]= (xsample>>8) & 0xff;
      ImageBuffer[2*ImageContent+1]= xsample & 0xff;
#endif
      ++ImageContent;
      return(1);
     }


 };
